@@ -1,7 +1,6 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#include <retro-gtk/retro-gtk.h>
-#include <retro-gtk/retro-core-view.h>
+#include <retro-gtk.h>
 
 #define RETRO_TYPE_DEMO_APPLICATION (retro_demo_application_get_type())
 
@@ -86,7 +85,6 @@ retro_demo_application_finalize (GObject *object)
   G_OBJECT_CLASS (retro_demo_application_parent_class)->finalize (object);
 }
 
-
 static void
 retro_demo_activate (GApplication *application)
 {
