@@ -1,7 +1,6 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef RETRO_CONTROLLER_TYPE_H
-#define RETRO_CONTROLLER_TYPE_H
+#pragma once
 
 #if !defined(__RETRO_GTK_INSIDE__) && !defined(RETRO_GTK_COMPILATION)
 # error "Only <retro-gtk.h> can be included directly."
@@ -24,6 +23,7 @@ GType retro_controller_type_get_type (void) G_GNUC_CONST;
  * @RETRO_CONTROLLER_TYPE_LIGHTGUN: a lightgun
  * @RETRO_CONTROLLER_TYPE_ANALOG: a gamepad with analog sticks
  * @RETRO_CONTROLLER_TYPE_POINTER: a screen pointer
+ * @RETRO_CONTROLLER_TYPE_COUNT: the number of types
  * @RETRO_CONTROLLER_TYPE_TYPE_MASK: a mask to get the super type of a derived one
  *
  * Represents the base types for Libretro controllers.
@@ -37,9 +37,8 @@ typedef enum
   RETRO_CONTROLLER_TYPE_LIGHTGUN,
   RETRO_CONTROLLER_TYPE_ANALOG,
   RETRO_CONTROLLER_TYPE_POINTER,
+  RETRO_CONTROLLER_TYPE_COUNT,
   RETRO_CONTROLLER_TYPE_TYPE_MASK = 0xff,
 } RetroControllerType;
 
 G_END_DECLS
-
-#endif /* RETRO_CONTROLLER_TYPE_H */
