@@ -1,7 +1,6 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef RETRO_CONTROLLER_H
-#define RETRO_CONTROLLER_H
+#pragma once
 
 #if !defined(__RETRO_GTK_INSIDE__) && !defined(RETRO_GTK_COMPILATION)
 # error "Only <retro-gtk.h> can be included directly."
@@ -26,6 +25,9 @@ struct _RetroControllerInterface
                              RetroInput      *input);
   RetroControllerType (*get_controller_type) (RetroController *self);
   guint64 (*get_capabilities) (RetroController *self);
+  gboolean (*set_rumble_state) (RetroController   *self,
+                                RetroRumbleEffect  effect,
+                                guint16            strength);
 };
 
 void retro_controller_poll (RetroController *self);
@@ -40,5 +42,3 @@ gboolean retro_controller_set_rumble_state (RetroController   *self,
                                             guint16            strength);
 
 G_END_DECLS
-
-#endif /* RETRO_CONTROLLER_H */
