@@ -1,20 +1,19 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef RETRO_CORE_PRIVATE_H
-#define RETRO_CORE_PRIVATE_H
+#pragma once
 
 #if !defined(__RETRO_GTK_INSIDE__) && !defined(RETRO_GTK_COMPILATION)
 # error "Only <retro-gtk.h> can be included directly."
 #endif
 
 #include "retro-core.h"
-#include "retro-disk-control-callback.h"
+#include "retro-disk-control-callback-private.h"
 #include "retro-input.h"
-#include "retro-input-descriptor.h"
-#include "retro-module.h"
+#include "retro-input-descriptor-private.h"
+#include "retro-module-private.h"
 #include "retro-option-private.h"
-#include "retro-pixel-format.h"
-#include "retro-rotation.h"
+#include "retro-pixel-format-private.h"
+#include "retro-rotation-private.h"
 
 G_BEGIN_DECLS
 
@@ -87,5 +86,3 @@ void retro_core_insert_variable (RetroCore           *self,
 gboolean retro_core_get_variable_update (RetroCore *self);
 
 G_END_DECLS
-
-#endif /* RETRO_CORE_PRIVATE_H */
