@@ -1,9 +1,9 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#include "retro-gl-display.h"
+#include "retro-gl-display-private.h"
 
 #include <epoxy/gl.h>
-#include "retro-glsl-filter.h"
+#include "retro-glsl-filter-private.h"
 #include "retro-pixbuf.h"
 #include "retro-pixdata.h"
 
@@ -561,6 +561,7 @@ retro_gl_display_get_coordinates_on_display (RetroGLDisplay *self,
   gdouble h = 0.0;
   gdouble x = 0.0;
   gdouble y = 0.0;
+  gint scale_factor;
 
   g_return_val_if_fail (RETRO_IS_GL_DISPLAY (self), FALSE);
   g_return_val_if_fail (display_x != NULL, FALSE);
@@ -568,6 +569,10 @@ retro_gl_display_get_coordinates_on_display (RetroGLDisplay *self,
 
   retro_gl_display_get_video_box (self, &w, &h, &x, &y);
 
+  scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (self));
+  widget_x *= scale_factor;
+  widget_y *= scale_factor;
+
   // Return coordinates as a [-1.0, 1.0] scale, (0.0, 0.0) is the center.
   *display_x = ((widget_x - x) * 2.0 - w) / w;
   *display_y = ((widget_y - y) * 2.0 - h) / h;
