@@ -1,14 +1,13 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#ifndef RETRO_INPUT_PRIVATE_H
-#define RETRO_INPUT_PRIVATE_H
+#pragma once
 
 #if !defined(__RETRO_GTK_INSIDE__) && !defined(RETRO_GTK_COMPILATION)
 # error "Only <retro-gtk.h> can be included directly."
 #endif
 
 #include "retro-input.h"
-#include "retro-keyboard-key.h"
+#include "retro-keyboard-key-private.h"
 
 G_BEGIN_DECLS
 
@@ -76,5 +75,3 @@ gboolean retro_input_get_keyboard (RetroInput       *self,
                                    RetroKeyboardKey *key);
 
 G_END_DECLS
-
-#endif /* RETRO_INPUT_PRIVATE_H */
