@@ -1,6 +1,6 @@
 // This file is part of retro-gtk. License: GPL-3.0+.
 
-#include "retro-option.h"
+#include "retro-option-private.h"
 
 struct _RetroOption
 {
@@ -8,11 +8,18 @@ struct _RetroOption
   gchar *key;
   gchar *description;
   gchar **values;
-  gchar *current;
+  gsize value;
 };
 
 G_DEFINE_TYPE (RetroOption, retro_option, G_TYPE_OBJECT)
 
+enum {
+  SIG_VALUE_CHANGED,
+  N_SIGNALS,
+};
+
+static guint signals[N_SIGNALS];
+
 #define RETRO_OPTION_ERROR (retro_option_error_quark ())
 
 enum {
@@ -33,7 +40,6 @@ retro_option_finalize (GObject *object)
   g_free (self->key);
   g_free (self->description);
   g_strfreev (self->values);
-  g_free (self->current);
 
   G_OBJECT_CLASS (retro_option_parent_class)->finalize (object);
 }
@@ -44,6 +50,13 @@ retro_option_class_init (RetroOptionClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->finalize = retro_option_finalize;
+
+  signals[SIG_VALUE_CHANGED] =
+    g_signal_new ("value-changed", RETRO_TYPE_OPTION, G_SIGNAL_RUN_LAST,
+                  0, NULL, NULL,
+                  g_cclosure_marshal_VOID__VOID,
+                  G_TYPE_NONE,
+                  0);
 }
 
 static void
@@ -53,6 +66,14 @@ retro_option_init (RetroOption *self)
 
 /* Public */
 
+/**
+ * retro_option_get_key:
+ * @self: a #RetroOption
+ *
+ * Gets the key of @self.
+ *
+ * Returns: (transfer none): the key of @self
+ */
 const gchar *
 retro_option_get_key (RetroOption *self)
 {
@@ -61,6 +82,14 @@ retro_option_get_key (RetroOption *self)
   return self->key;
 }
 
+/**
+ * retro_option_get_description:
+ * @self: a #RetroOption
+ *
+ * Gets the description of @self.
+ *
+ * Returns: (transfer none): the description of @self
+ */
 const gchar *
 retro_option_get_description (RetroOption *self)
 {
@@ -69,6 +98,15 @@ retro_option_get_description (RetroOption *self)
   return self->description;
 }
 
+/**
+ * retro_option_get_values:
+ * @self: a #RetroOption
+ *
+ * Gets the value of @self.
+ *
+ * Returns: (array zero-terminated=1) (element-type utf8) (transfer none): the
+ * value of @self
+ */
 const gchar **
 retro_option_get_values (RetroOption *self)
 {
@@ -77,37 +115,62 @@ retro_option_get_values (RetroOption *self)
   return (const gchar **) self->values;
 }
 
+/**
+ * retro_option_get_value:
+ * @self: a #RetroOption
+ *
+ * Gets the value of @self.
+ *
+ * Returns: (transfer none): the value of @self
+ */
 const gchar *
-retro_option_get_current (RetroOption *self)
+retro_option_get_value (RetroOption *self)
 {
   g_return_val_if_fail (RETRO_IS_OPTION (self), NULL);
 
-  return self->current;
+  return self->values[self->value];
 }
 
+/**
+ * retro_option_set_value:
+ * @self: a #RetroOption
+ * @value: the value
+ * @error: return location for a #GError, or %NULL
+ *
+ * Sets the value for @self. An error will be thrown if the value is invalid for
+ * @self.
+ */
 void
-retro_option_set_current (RetroOption  *self,
-                          const gchar  *current,
-                          GError      **error)
+retro_option_set_value (RetroOption  *self,
+                        const gchar  *value,
+                        GError      **error)
 {
-  g_return_if_fail (RETRO_IS_OPTION (self));
-  g_return_if_fail (current != NULL);
+  gsize i;
 
-  g_message ("%s, %s", self->current, current);
-  if (g_strcmp0 (self->current, current) == 0)
+  g_return_if_fail (RETRO_IS_OPTION (self));
+  g_return_if_fail (value != NULL);
+
+  if (g_strcmp0 (self->values[self->value], value) == 0)
     return;
 
-  if (G_UNLIKELY (g_strv_contains ((const gchar *const *) self->values, current))) {
-    g_set_error_literal (error,
-                         RETRO_OPTION_ERROR,
-                         RETRO_OPTION_ERROR_INVALID_VALUE,
-                         "Unexpected option value: option %s doesn’t have value %s.");
+  for (i = 0; self->values[i] != NULL; i++)
+    if (g_strcmp0 (self->values[i], value) == 0)
+      break;
+
+  if (G_UNLIKELY (self->values[i] == NULL)) {
+    g_set_error (error,
+                 RETRO_OPTION_ERROR,
+                 RETRO_OPTION_ERROR_INVALID_VALUE,
+                 "Unexpected option value: option %s doesn’t have value %s.",
+                 self->key,
+                 value);
 
     return;
   }
 
-  g_free (self->current);
-  self->current = g_strdup (current);
+  self->value = i;
+
+  g_signal_emit (self, signals[SIG_VALUE_CHANGED], 0);
 }
 
 RetroOption *
@@ -150,7 +213,6 @@ retro_option_new (const RetroVariable  *variable,
   self->description = g_strndup (variable->value,
                                  description_separator - variable->value);
   self->values = values;
-  self->current = g_strdup (values[0]);
 
   return self;
 }
